@@ -167,12 +167,12 @@ class DenseRetrievalExactSearch:
                     self.corpus_embeddings[request_qid].append(sub_corpus_embeddings)
 
             # Compute similarites using self defined similarity otherwise default to cosine-similarity
-            similarity_scores = cos_sim(query_embeddings, sub_corpus_embeddings)
             if hasattr(self.model, "similarity"):
                 similarity_scores = self.model.similarity(
-                    float(self.model.similarity(e1, e2))
-                    for e1, e2 in zip(query_embeddings, sub_corpus_embeddings)
+                    query_embeddings, sub_corpus_embeddings
                 )
+            else:
+                similarity_scores = cos_sim(query_embeddings, sub_corpus_embeddings)
             is_nan = torch.isnan(similarity_scores)
             if is_nan.sum() > 0:
                 logger.warning(
@@ -261,7 +261,7 @@ class DenseRetrievalExactSearch:
                 logging.info(
                     f"previous_results is None. Using all the documents to rerank: {len(corpus)}"
                 )
-                q_results = {doc_id: 0.0 for doc_id in corpus.keys()}
+                q_results = dict.fromkeys(corpus.keys(), 0.0)
             else:
                 q_results = self.previous_results[qid]
             # take the top-k only
@@ -371,11 +371,15 @@ class DRESModel:
     mteb_model_meta: ModelMeta | None
 
     def __init__(self, model, **kwargs):
-        self.model = model
+        self.model: Any = model
         self.use_sbert_model = isinstance(model, SentenceTransformer)
+        self.device = model.device if hasattr(model, "device") else None
         self.save_corpus_embeddings = kwargs.get("save_corpus_embeddings", False)
         self.corpus_embeddings = {}
 
+        if hasattr(self.model, "similarity") and callable(self.model.similarity):
+            self.similarity = self.model.similarity
+
     def encode_corpus(
         self,
         corpus: list[dict[str, str]],
@@ -474,6 +478,7 @@ class RetrievalEvaluator(Evaluator):
                 corpus,
                 queries,
                 self.top_k,
+                score_function="bm25",
                 task_name=self.task_name,  # type: ignore
             )
         else:
