@@ -5,20 +5,17 @@ from functools import partial
 
 from mteb.evaluation.evaluators.RetrievalEvaluator import DRESModel
 from mteb.model_meta import ModelMeta
-
-from .wrapper import Wrapper
+from mteb.models.wrapper import Wrapper
+from mteb.requires_package import requires_package
 
 logger = logging.getLogger(__name__)
 
 
 def bm25_loader(**kwargs):
-    try:
-        import bm25s
-        import Stemmer
-    except ImportError:
-        raise ImportError(
-            "bm25s or PyStemmer is not installed. Please install it with `pip install mteb[bm25s]`."
-        )
+    model_name = kwargs.get("model_name", "BM25")
+    requires_package(bm25_loader, "bm25s", model_name, "pip install mteb[bm25s]")
+    import bm25s
+    import Stemmer
 
     class BM25Search(DRESModel, Wrapper):
         """BM25 search"""
@@ -126,17 +123,20 @@ def bm25_loader(**kwargs):
 bm25_s = ModelMeta(
     loader=partial(bm25_loader, model_name="bm25s"),  # type: ignore
     name="bm25s",
-    languages=["eng_Latn"],
+    languages=["eng-Latn"],
     open_weights=True,
     revision="0_1_10",
     release_date="2024-07-10",  ## release of version 0.1.10
     n_parameters=None,
-    memory_usage=None,
+    memory_usage_mb=None,
     embed_dim=None,
     license=None,
     max_tokens=None,
-    reference=None,
+    reference="https://github.com/xhluca/bm25s",
     similarity_fn_name=None,
     framework=[],
     use_instructions=False,
+    public_training_code="https://github.com/xhluca/bm25s",
+    public_training_data=None,
+    training_datasets=None,
 )
