@@ -7,105 +7,105 @@ from mteb.model_meta import ModelMeta, sentence_transformers_loader
 
 E5_PAPER_RELEASE_DATE = "2024-02-08"
 XLMR_LANGUAGES = [
-    "afr_Latn",
-    "amh_Latn",
-    "ara_Latn",
-    "asm_Latn",
-    "aze_Latn",
-    "bel_Latn",
-    "bul_Latn",
-    "ben_Latn",
-    "ben_Beng",
-    "bre_Latn",
-    "bos_Latn",
-    "cat_Latn",
-    "ces_Latn",
-    "cym_Latn",
-    "dan_Latn",
-    "deu_Latn",
-    "ell_Latn",
-    "eng_Latn",
-    "epo_Latn",
-    "spa_Latn",
-    "est_Latn",
-    "eus_Latn",
-    "fas_Latn",
-    "fin_Latn",
-    "fra_Latn",
-    "fry_Latn",
-    "gle_Latn",
-    "gla_Latn",
-    "glg_Latn",
-    "guj_Latn",
-    "hau_Latn",
-    "heb_Latn",
-    "hin_Latn",
-    "hin_Deva",
-    "hrv_Latn",
-    "hun_Latn",
-    "hye_Latn",
-    "ind_Latn",
-    "isl_Latn",
-    "ita_Latn",
-    "jpn_Latn",
-    "jav_Latn",
-    "kat_Latn",
-    "kaz_Latn",
-    "khm_Latn",
-    "kan_Latn",
-    "kor_Latn",
-    "kur_Latn",
-    "kir_Latn",
-    "lat_Latn",
-    "lao_Latn",
-    "lit_Latn",
-    "lav_Latn",
-    "mlg_Latn",
-    "mkd_Latn",
-    "mal_Latn",
-    "mon_Latn",
-    "mar_Latn",
-    "msa_Latn",
-    "mya_Latn",
-    "nep_Latn",
-    "nld_Latn",
-    "nob_Latn",
-    "orm_Latn",
-    "ori_Latn",
-    "pan_Latn",
-    "pol_Latn",
-    "pus_Latn",
-    "por_Latn",
-    "ron_Latn",
-    "rus_Latn",
-    "san_Latn",
-    "snd_Latn",
-    "sin_Latn",
-    "slk_Latn",
-    "slv_Latn",
-    "som_Latn",
-    "sqi_Latn",
-    "srp_Latn",
-    "sun_Latn",
-    "swe_Latn",
-    "swa_Latn",
-    "tam_Latn",
-    "tam_Taml",
-    "tel_Latn",
-    "tel_Telu",
-    "tha_Latn",
-    "tgl_Latn",
-    "tur_Latn",
-    "uig_Latn",
-    "ukr_Latn",
-    "urd_Latn",
-    "urd_Arab",
-    "uzb_Latn",
-    "vie_Latn",
-    "xho_Latn",
-    "yid_Latn",
-    "zho_Hant",
-    "zho_Hans",
+    "afr-Latn",
+    "amh-Latn",
+    "ara-Latn",
+    "asm-Latn",
+    "aze-Latn",
+    "bel-Latn",
+    "bul-Latn",
+    "ben-Latn",
+    "ben-Beng",
+    "bre-Latn",
+    "bos-Latn",
+    "cat-Latn",
+    "ces-Latn",
+    "cym-Latn",
+    "dan-Latn",
+    "deu-Latn",
+    "ell-Latn",
+    "eng-Latn",
+    "epo-Latn",
+    "spa-Latn",
+    "est-Latn",
+    "eus-Latn",
+    "fas-Latn",
+    "fin-Latn",
+    "fra-Latn",
+    "fry-Latn",
+    "gle-Latn",
+    "gla-Latn",
+    "glg-Latn",
+    "guj-Latn",
+    "hau-Latn",
+    "heb-Latn",
+    "hin-Latn",
+    "hin-Deva",
+    "hrv-Latn",
+    "hun-Latn",
+    "hye-Latn",
+    "ind-Latn",
+    "isl-Latn",
+    "ita-Latn",
+    "jpn-Latn",
+    "jav-Latn",
+    "kat-Latn",
+    "kaz-Latn",
+    "khm-Latn",
+    "kan-Latn",
+    "kor-Latn",
+    "kur-Latn",
+    "kir-Latn",
+    "lat-Latn",
+    "lao-Latn",
+    "lit-Latn",
+    "lav-Latn",
+    "mlg-Latn",
+    "mkd-Latn",
+    "mal-Latn",
+    "mon-Latn",
+    "mar-Latn",
+    "msa-Latn",
+    "mya-Latn",
+    "nep-Latn",
+    "nld-Latn",
+    "nob-Latn",
+    "orm-Latn",
+    "ori-Latn",
+    "pan-Latn",
+    "pol-Latn",
+    "pus-Latn",
+    "por-Latn",
+    "ron-Latn",
+    "rus-Latn",
+    "san-Latn",
+    "snd-Latn",
+    "sin-Latn",
+    "slk-Latn",
+    "slv-Latn",
+    "som-Latn",
+    "sqi-Latn",
+    "srp-Latn",
+    "sun-Latn",
+    "swe-Latn",
+    "swa-Latn",
+    "tam-Latn",
+    "tam-Taml",
+    "tel-Latn",
+    "tel-Telu",
+    "tha-Latn",
+    "tgl-Latn",
+    "tur-Latn",
+    "uig-Latn",
+    "ukr-Latn",
+    "urd-Latn",
+    "urd-Arab",
+    "uzb-Latn",
+    "vie-Latn",
+    "xho-Latn",
+    "yid-Latn",
+    "zho-Hant",
+    "zho-Hans",
 ]
 
 model_prompts = {
@@ -113,6 +113,37 @@ model_prompts = {
     PromptType.passage.value: "passage: ",
 }
 
+E5_TRAINING_DATA = {
+    # from 4.2 in https://arxiv.org/pdf/2212.03533
+    # also pre-training data from a variety of sources (stackexchange, semantic scholar, reddit, CC, ...)
+    "MSMARCO": ["train"],
+    "MSMARCOHardNegatives": ["train"],
+    "NanoMSMARCORetrieval": ["train"],
+    "MSMARCO-PL": ["train"],  # translation not trained on
+    "mMARCO-NL": ["train"],  # translation not trained on
+    "NQ": ["train"],
+    "NQHardNegatives": ["train"],
+    "NanoNQRetrieval": ["train"],
+    "NQ-PL": ["train"],  # translation not trained on
+    "NQ-NL": ["train"],  # translation not trained on
+}
+
+ME5_TRAINING_DATA = {
+    **E5_TRAINING_DATA,
+    "XQuADRetrieval": ["train"],  # trained on SQuAD train dataset
+    "FEVER": ["train"],
+    "FEVERHardNegatives": ["train"],
+    "FEVER-NL": ["train"],  # translation not trained on
+    "HotpotQA": ["train"],
+    "HotpotQAHardNegatives": ["train"],
+    "HotpotQA-PL": ["train"],  # translation not trained on
+    "HotpotQA-NL": ["train"],  # translation not trained on
+    "MIRACLRetrieval": ["train"],
+    "MIRACLRetrievalHardNegatives": ["train"],
+    "MIRACLReranking": ["train"],
+    "MrTidyRetrieval": ["train"],
+}
+
 e5_mult_small = ModelMeta(
     loader=partial(  # type: ignore
         sentence_transformers_loader,
@@ -126,7 +157,7 @@ e5_mult_small = ModelMeta(
     revision="fd1525a9fd15316a2d503bf26ab031a61d056e98",
     release_date=E5_PAPER_RELEASE_DATE,
     n_parameters=118_000_000,
-    memory_usage=None,
+    memory_usage_mb=449,
     embed_dim=384,
     license="mit",
     max_tokens=512,
@@ -134,6 +165,10 @@ e5_mult_small = ModelMeta(
     similarity_fn_name="cosine",
     framework=["Sentence Transformers", "PyTorch"],
     use_instructions=True,
+    public_training_code=None,
+    public_training_data=None,
+    training_datasets=ME5_TRAINING_DATA,
+    adapted_from="microsoft/Multilingual-MiniLM-L12-H384",
 )
 
 e5_mult_base = ModelMeta(
@@ -148,7 +183,7 @@ e5_mult_base = ModelMeta(
     revision="d13f1b27baf31030b7fd040960d60d909913633f",
     release_date=E5_PAPER_RELEASE_DATE,
     n_parameters=278_000_000,
-    memory_usage=None,
+    memory_usage_mb=1061,
     embed_dim=768,
     license="mit",
     max_tokens=514,
@@ -156,6 +191,10 @@ e5_mult_base = ModelMeta(
     similarity_fn_name="cosine",
     framework=["Sentence Transformers", "PyTorch"],
     use_instructions=True,
+    public_training_code=None,
+    public_training_data=None,
+    adapted_from="FacebookAI/xlm-roberta-base",
+    training_datasets=ME5_TRAINING_DATA,
 )
 
 e5_mult_large = ModelMeta(
@@ -171,7 +210,7 @@ e5_mult_large = ModelMeta(
     revision="ab10c1a7f42e74530fe7ae5be82e6d4f11a719eb",
     release_date=E5_PAPER_RELEASE_DATE,
     n_parameters=560_000_000,
-    memory_usage=None,
+    memory_usage_mb=2136,
     embed_dim=1024,
     license="mit",
     max_tokens=514,
@@ -179,6 +218,10 @@ e5_mult_large = ModelMeta(
     similarity_fn_name="cosine",
     framework=["Sentence Transformers", "PyTorch"],
     use_instructions=True,
+    public_training_code=None,
+    public_training_data=None,
+    training_datasets=ME5_TRAINING_DATA,
+    adapted_from="FacebookAI/xlm-roberta-large",
 )
 
 e5_eng_small_v2 = ModelMeta(
@@ -188,12 +231,12 @@ e5_eng_small_v2 = ModelMeta(
         model_prompts=model_prompts,
     ),
     name="intfloat/e5-small-v2",
-    languages=["eng_Latn"],
+    languages=["eng-Latn"],
     open_weights=True,
     revision="dca8b1a9dae0d4575df2bf423a5edb485a431236",
     release_date=E5_PAPER_RELEASE_DATE,
     n_parameters=33_000_000,
-    memory_usage=None,
+    memory_usage_mb=127,
     embed_dim=384,
     license="mit",
     max_tokens=512,
@@ -201,6 +244,10 @@ e5_eng_small_v2 = ModelMeta(
     similarity_fn_name="cosine",
     framework=["Sentence Transformers", "PyTorch"],
     use_instructions=True,
+    public_training_code=None,
+    public_training_data=None,
+    adapted_from="intfloat/e5-small",
+    training_datasets=E5_TRAINING_DATA,
 )
 
 e5_eng_small = ModelMeta(
@@ -211,12 +258,12 @@ e5_eng_small = ModelMeta(
         model_prompts=model_prompts,
     ),
     name="intfloat/e5-small",
-    languages=["eng_Latn"],
+    languages=["eng-Latn"],
     open_weights=True,
     revision="e272f3049e853b47cb5ca3952268c6662abda68f",
     release_date=E5_PAPER_RELEASE_DATE,
     n_parameters=33_000_000,
-    memory_usage=None,
+    memory_usage_mb=127,
     embed_dim=384,
     license="mit",
     max_tokens=512,
@@ -224,6 +271,10 @@ e5_eng_small = ModelMeta(
     similarity_fn_name="cosine",
     framework=["Sentence Transformers", "PyTorch"],
     use_instructions=True,
+    public_training_code=None,
+    public_training_data=None,
+    training_datasets=E5_TRAINING_DATA,
+    adapted_from="sentence-transformers/all-MiniLM-L6-v2",
 )
 
 e5_eng_base_v2 = ModelMeta(
@@ -234,12 +285,12 @@ e5_eng_base_v2 = ModelMeta(
         model_prompts=model_prompts,
     ),
     name="intfloat/e5-base-v2",
-    languages=["eng_Latn"],
+    languages=["eng-Latn"],
     open_weights=True,
     revision="1c644c92ad3ba1efdad3f1451a637716616a20e8",
     release_date=E5_PAPER_RELEASE_DATE,
     n_parameters=109_000_000,
-    memory_usage=None,
+    memory_usage_mb=418,
     embed_dim=768,
     license="mit",
     max_tokens=512,
@@ -248,7 +299,10 @@ e5_eng_base_v2 = ModelMeta(
     framework=["Sentence Transformers", "PyTorch"],
     use_instructions=True,
     superseded_by=None,
-    adapted_from=None,
+    adapted_from="intfloat/e5-base",
+    public_training_code=None,
+    public_training_data=None,
+    training_datasets=E5_TRAINING_DATA,
 )
 
 e5_eng_large_v2 = ModelMeta(
@@ -259,12 +313,12 @@ e5_eng_large_v2 = ModelMeta(
         model_prompts=model_prompts,
     ),
     name="intfloat/e5-large-v2",
-    languages=["eng_Latn"],
+    languages=["eng-Latn"],
     open_weights=True,
     revision="b322e09026e4ea05f42beadf4d661fb4e101d311",
     release_date=E5_PAPER_RELEASE_DATE,
     n_parameters=335_000_000,
-    memory_usage=None,
+    memory_usage_mb=1278,
     embed_dim=1024,
     license="mit",
     max_tokens=514,
@@ -273,7 +327,10 @@ e5_eng_large_v2 = ModelMeta(
     framework=["Sentence Transformers", "PyTorch"],
     use_instructions=True,
     superseded_by=None,
-    adapted_from=None,
+    adapted_from="intfloat/e5-large",
+    public_training_code=None,
+    public_training_data=None,
+    training_datasets=E5_TRAINING_DATA,
 )
 
 e5_large = ModelMeta(
@@ -289,7 +346,7 @@ e5_large = ModelMeta(
     revision="4dc6d853a804b9c8886ede6dda8a073b7dc08a81",
     release_date="2022-12-26",
     n_parameters=335_000_000,
-    memory_usage=None,
+    memory_usage_mb=1278,
     embed_dim=1024,
     license="apache-2.0",
     max_tokens=512,
@@ -298,7 +355,10 @@ e5_large = ModelMeta(
     framework=["Sentence Transformers", "PyTorch"],
     use_instructions=True,
     superseded_by="intfloat/e5-large-v2",
-    adapted_from=None,
+    adapted_from="google-bert/bert-large-uncased-whole-word-masking",
+    public_training_code=None,
+    public_training_data=None,
+    training_datasets=E5_TRAINING_DATA,
 )
 
 e5_base = ModelMeta(
@@ -314,7 +374,7 @@ e5_base = ModelMeta(
     revision="b533fe4636f4a2507c08ddab40644d20b0006d6a",
     release_date="2022-12-26",
     n_parameters=109_000_000,
-    memory_usage=None,
+    memory_usage_mb=418,
     embed_dim=768,
     license="apache-2.0",
     max_tokens=512,
@@ -323,5 +383,8 @@ e5_base = ModelMeta(
     framework=["Sentence Transformers", "PyTorch"],
     use_instructions=True,
     superseded_by="intfloat/e5-base-v2",
-    adapted_from=None,
+    adapted_from="google-bert/bert-base-uncased",
+    public_training_code=None,
+    public_training_data=None,
+    training_datasets=E5_TRAINING_DATA,
 )
