@@ -8,40 +8,48 @@ import tqdm
 
 from mteb.encoder_interface import Encoder, PromptType
 from mteb.model_meta import ModelMeta
-
-from .wrapper import Wrapper
+from mteb.models.wrapper import Wrapper
+from mteb.requires_package import requires_package
 
 MULTILINGUAL_EVALUATED_LANGUAGES = [
-    "arb_Arab",
-    "ben_Beng",
-    "eng_Latn",
-    "spa_Latn",
-    "deu_Latn",
-    "pes_Arab",
-    "fin_Latn",
-    "fra_Latn",
-    "hin_Deva",
-    "ind_Latn",
-    "jpn_Jpan",
-    "kor_Hang",
-    "rus_Cyrl",
-    "swh_Latn",
-    "tel_Telu",
-    "tha_Thai",
-    "yor_Latn",
-    "zho_Hant",
-    "zho_Hans",
+    "arb-Arab",
+    "ben-Beng",
+    "eng-Latn",
+    "spa-Latn",
+    "deu-Latn",
+    "pes-Arab",
+    "fin-Latn",
+    "fra-Latn",
+    "hin-Deva",
+    "ind-Latn",
+    "jpn-Jpan",
+    "kor-Hang",
+    "rus-Cyrl",
+    "swh-Latn",
+    "tel-Telu",
+    "tha-Thai",
+    "yor-Latn",
+    "zho-Hant",
+    "zho-Hans",
 ]
 
 MODEL_PROMPTS = {
     "Classification": "CLASSIFICATION",
     "MultilabelClassification": "CLASSIFICATION",
     "Clustering": "CLUSTERING",
-    "STS": "SIMILARITY",
+    "STS": "SEMANTIC_SIMILARITY",
     PromptType.query.value: "RETRIEVAL_QUERY",
     PromptType.passage.value: "RETRIEVAL_DOCUMENT",
 }
 
+GECKO_TRAINING_DATA = {
+    # Ones that are available from HF.
+    "NQHardNegatives": ["train"],
+    "FEVERHardNegatives": ["train"],
+    "HotpotQAHardNegatives": ["train"],
+    "MIRACLRetrievalHardNegatives": ["train"],
+}
+
 
 class GoogleTextEmbeddingModel(Encoder, Wrapper):
     def __init__(
@@ -67,12 +75,11 @@ class GoogleTextEmbeddingModel(Encoder, Wrapper):
         """Embeds texts with a pre-trained, foundational model.
         From https://cloud.google.com/vertex-ai/generative-ai/docs/embeddings/get-text-embeddings#generative-ai-get-text-embedding-python_vertex_ai_sdk
         """
-        try:
-            from vertexai.language_models import TextEmbeddingInput, TextEmbeddingModel
-        except ImportError:
-            raise ImportError(
-                "The `vertexai` package is required to run the google API, please install it using `pip install vertexai`"
-            )
+        requires_package(
+            self, "vertexai", self.model_name, "pip install 'mteb[vertexai]'"
+        )
+        from vertexai.language_models import TextEmbeddingInput, TextEmbeddingModel
+
         model = TextEmbeddingModel.from_pretrained(self.model_name)
         if titles:
             # Allow title-only embeddings by replacing text with a space
@@ -145,13 +152,17 @@ google_text_emb_004 = ModelMeta(
     revision="1",  # revision is intended for implementation
     release_date="2024-05-14",
     n_parameters=None,
-    memory_usage=None,
+    memory_usage_mb=None,
     max_tokens=2048,
     embed_dim=768,
     license=None,
-    similarity_fn_name="cosine",  # assumed
+    reference="https://cloud.google.com/vertex-ai/generative-ai/docs/embeddings/get-text-embeddings",
+    similarity_fn_name="cosine",
     framework=["API"],
     use_instructions=True,
+    public_training_code=None,
+    public_training_data=None,
+    training_datasets=GECKO_TRAINING_DATA,
 )
 
 google_text_emb_005 = ModelMeta(
@@ -166,13 +177,17 @@ google_text_emb_005 = ModelMeta(
     revision="1",  # revision is intended for implementation
     release_date="2024-11-18",
     n_parameters=None,
-    memory_usage=None,
+    memory_usage_mb=None,
     max_tokens=2048,
     embed_dim=768,
     license=None,
-    similarity_fn_name="cosine",  # assumed
+    reference="https://cloud.google.com/vertex-ai/generative-ai/docs/embeddings/get-text-embeddings",
+    similarity_fn_name="cosine",
     framework=["API"],
     use_instructions=True,
+    public_training_code=None,
+    public_training_data=None,
+    training_datasets=GECKO_TRAINING_DATA,
 )
 
 google_text_multilingual_emb_002 = ModelMeta(
@@ -184,14 +199,43 @@ google_text_multilingual_emb_002 = ModelMeta(
     name="google/text-multilingual-embedding-002",
     languages=MULTILINGUAL_EVALUATED_LANGUAGES,  # From the list of evaluated languages in https://cloud.google.com/vertex-ai/generative-ai/docs/model-reference/text-embeddings-api#supported_text_languages
     open_weights=False,
-    revision="1",  # revision is intended for implementation
+    revision="1",
     release_date="2024-05-14",
     n_parameters=None,
-    memory_usage=None,
+    memory_usage_mb=None,
     max_tokens=2048,
     embed_dim=768,
     license=None,
-    similarity_fn_name="cosine",  # assumed
+    reference="https://cloud.google.com/vertex-ai/generative-ai/docs/embeddings/get-text-embeddings",
+    similarity_fn_name="cosine",
     framework=["API"],
     use_instructions=True,
+    public_training_code=None,
+    public_training_data=None,
+    training_datasets=GECKO_TRAINING_DATA,
+)
+
+google_gemini_embedding_001 = ModelMeta(
+    loader=partial(
+        GoogleTextEmbeddingModel,
+        model_name="gemini-embedding-001",
+        model_prompts=MODEL_PROMPTS,
+    ),
+    name="google/gemini-embedding-001",
+    languages=MULTILINGUAL_EVALUATED_LANGUAGES,
+    open_weights=False,
+    revision="1",
+    release_date="2025-03-07",
+    n_parameters=None,
+    memory_usage_mb=None,
+    max_tokens=2048,
+    embed_dim=3072,
+    license=None,
+    reference="https://cloud.google.com/vertex-ai/generative-ai/docs/embeddings/get-text-embeddings",
+    similarity_fn_name="cosine",
+    framework=["API"],
+    use_instructions=True,
+    public_training_code=None,
+    public_training_data=None,
+    training_datasets=GECKO_TRAINING_DATA,
 )
