@@ -12,82 +12,185 @@ from mteb.abstasks.AbsTask import AbsTask
 from mteb.encoder_interface import Encoder
 from mteb.model_meta import ModelMeta
 from mteb.models import (
+    align_models,
+    ara_models,
     arctic_models,
+    b1ade_models,
+    bedrock_models,
     bge_models,
+    blip2_models,
+    blip_models,
     bm25,
+    cadet_models,
+    cde_models,
+    clip_models,
+    codesage_models,
     cohere_models,
+    cohere_v,
     colbert_models,
+    colpali_models,
+    colqwen_models,
+    colsmol_models,
+    conan_models,
+    dino_models,
     e5_instruct,
     e5_models,
+    e5_v,
+    evaclip_models,
+    fa_models,
+    geogpt_models,
+    gme_v_models,
     google_models,
     gritlm_models,
     gte_models,
+    hinvec_models,
     ibm_granite_models,
+    inf_models,
     jasper_models,
+    jina_clip,
     jina_models,
+    kalm_models,
+    lens_models,
+    lgai_embedding_models,
     linq_models,
+    listconranker,
+    llm2clip_models,
     llm2vec_models,
+    mcinext_models,
     misc_models,
+    moco_models,
     model2vec_models,
+    moka_models,
     mxbai_models,
+    nb_sbert,
     no_instruct_sentence_models,
     nomic_models,
+    nomic_models_vision,
+    nvidia_llama_nemoretriever_colemb,
     nvidia_models,
     openai_models,
+    openclip_models,
+    ops_moa_models,
+    piccolo_models,
     promptriever_models,
+    qodo_models,
+    qtack_models,
+    qwen3_models,
     repllama_models,
     rerankers_custom,
     rerankers_monot5_based,
+    richinfoai_models,
     ru_sentence_models,
     salesforce_models,
+    searchmap_models,
+    seed_1_6_embedding_models,
+    seed_models,
     sentence_transformers_models,
+    shuu_model,
+    siglip_models,
+    sonar_models,
     stella_models,
+    text2vec_models,
+    ua_sentence_models,
     uae_models,
+    vdr_models,
+    vista_models,
+    vlm2vec_models,
     voyage_models,
+    voyage_v,
+    xyz_models,
 )
 
 logger = logging.getLogger(__name__)
 
 model_modules = [
+    xyz_models,
+    align_models,
     arctic_models,
+    bedrock_models,
     bge_models,
+    blip2_models,
+    blip_models,
     bm25,
+    cadet_models,
+    clip_models,
+    codesage_models,
+    cde_models,
     cohere_models,
+    cohere_v,
     colbert_models,
+    conan_models,
+    dino_models,
     e5_instruct,
     e5_models,
-    google_models,
+    e5_v,
+    evaclip_models,
     google_models,
     gritlm_models,
     gte_models,
+    hinvec_models,
     ibm_granite_models,
+    inf_models,
+    jasper_models,
     jina_models,
+    jina_clip,
+    kalm_models,
+    lens_models,
+    lgai_embedding_models,
     linq_models,
+    listconranker,
+    llm2clip_models,
     llm2vec_models,
-    mxbai_models,
-    model2vec_models,
     misc_models,
-    nomic_models,
+    model2vec_models,
+    moka_models,
+    moco_models,
+    mxbai_models,
     no_instruct_sentence_models,
+    nomic_models,
+    nomic_models_vision,
     nvidia_models,
+    nvidia_llama_nemoretriever_colemb,
     openai_models,
+    openclip_models,
+    ops_moa_models,
+    piccolo_models,
+    gme_v_models,
     promptriever_models,
+    qodo_models,
+    qtack_models,
+    qwen3_models,
     repllama_models,
     rerankers_custom,
     rerankers_monot5_based,
+    richinfoai_models,
     ru_sentence_models,
+    ua_sentence_models,
+    seed_models,
+    seed_1_6_embedding_models,
     salesforce_models,
+    searchmap_models,
     sentence_transformers_models,
-    voyage_models,
-    google_models,
-    repllama_models,
-    promptriever_models,
-    jina_models,
-    jasper_models,
-    uae_models,
+    shuu_model,
+    siglip_models,
+    vista_models,
+    vlm2vec_models,
+    voyage_v,
     stella_models,
+    sonar_models,
+    text2vec_models,
     uae_models,
     voyage_models,
+    vdr_models,
+    fa_models,
+    ara_models,
+    b1ade_models,
+    nb_sbert,
+    colpali_models,
+    colqwen_models,
+    colsmol_models,
+    geogpt_models,
+    mcinext_models,
 ]
 MODEL_REGISTRY = {}
 
@@ -106,7 +209,18 @@ def get_model_metas(
     use_instructions: bool | None = None,
     zero_shot_on: list[AbsTask] | None = None,
 ) -> list[ModelMeta]:
-    """Load all models' metadata that fit the specified criteria."""
+    """Load all models' metadata that fit the specified criteria.
+
+    Args:
+        model_names: A list of model names to filter by. If None, all models are included.
+        languages: A list of languages to filter by. If None, all languages are included.
+        open_weights: Whether to filter by models with open weights. If None this filter is ignored.
+        frameworks: A list of frameworks to filter by. If None, all frameworks are included.
+        n_parameters_range: A tuple of lower and upper bounds of the number of parameters to filter by.
+            If (None, None), this filter is ignored.
+        use_instructions: Whether to filter by models that use instructions. If None, all models are included.
+        zero_shot_on: A list of tasks on which the model is zero-shot. If None this filter is ignored.
+    """
     res = []
     model_names = set(model_names) if model_names is not None else None
     languages = set(languages) if languages is not None else None
@@ -127,14 +241,16 @@ def get_model_metas(
             model_meta.use_instructions != use_instructions
         ):
             continue
+
         lower, upper = n_parameters_range
         n_parameters = model_meta.n_parameters
+
         if upper is not None:
             if (n_parameters is None) or (n_parameters > upper):
                 continue
-        if lower is not None:
-            if (n_parameters is None) or (n_parameters < lower):
+            if lower is not None and n_parameters < lower:
                 continue
+
         if zero_shot_on is not None:
             if not model_meta.is_zero_shot_on(zero_shot_on):
                 continue
@@ -165,12 +281,15 @@ def get_model(model_name: str, revision: str | None = None, **kwargs: Any) -> En
     return model
 
 
-def get_model_meta(model_name: str, revision: str | None = None) -> ModelMeta:
+def get_model_meta(
+    model_name: str, revision: str | None = None, fetch_from_hf: bool = True
+) -> ModelMeta:
     """A function to fetch a model metadata object by name.
 
     Args:
         model_name: Name of the model to fetch
         revision: Revision of the model to fetch
+        fetch_from_hf: Whether to fetch the model from HuggingFace Hub if not found in the registry
 
     Returns:
         A model metadata object
@@ -182,6 +301,10 @@ def get_model_meta(model_name: str, revision: str | None = None) -> ModelMeta:
             )
         return MODEL_REGISTRY[model_name]
     else:  # assume it is a sentence-transformers model
+        if not fetch_from_hf:
+            raise ValueError(
+                f"Model {model_name} not found in MTEB registry. Please set fetch_from_hf=False to load it from HuggingFace Hub."
+            )
         logger.info(
             "Model not found in model registry, assuming it is on HF Hub model."
         )
@@ -204,22 +327,43 @@ def model_meta_from_hf_hub(model_name: str) -> ModelMeta:
             frameworks.append("Sentence Transformers")
         return ModelMeta(
             name=model_name,
-            revision=None,
+            revision=card_data.get("base_model_revision", None),
             # TODO
             release_date=None,
             # TODO: We need a mapping between conflicting language codes
             languages=None,
             license=card_data.get("license", None),
-            framework=frameworks,
-            public_training_data=bool(card_data.get("datasets", None)),
+            framework=frameworks,  # type: ignore
+            training_datasets=card_data.get("datasets", None),
+            similarity_fn_name=None,
+            n_parameters=None,
+            memory_usage_mb=None,
+            max_tokens=None,
+            embed_dim=None,
+            open_weights=True,
+            public_training_code=None,
+            public_training_data=None,
+            use_instructions=None,
         )
     except Exception as e:
         logger.warning(f"Failed to extract metadata from model: {e}.")
         return ModelMeta(
-            name=None,
+            name=model_name,
             revision=None,
             languages=None,
             release_date=None,
+            n_parameters=None,
+            memory_usage_mb=None,
+            max_tokens=None,
+            embed_dim=None,
+            license=None,
+            open_weights=True,
+            public_training_code=None,
+            public_training_data=None,
+            similarity_fn_name=None,
+            use_instructions=None,
+            training_datasets=None,
+            framework=[],
         )
 
 
@@ -242,6 +386,16 @@ def model_meta_from_sentence_transformers(model: SentenceTransformer) -> ModelMe
             languages=languages,
             framework=["Sentence Transformers"],
             similarity_fn_name=model.similarity_fn_name,
+            n_parameters=None,
+            memory_usage_mb=None,
+            max_tokens=None,
+            embed_dim=None,
+            license=None,
+            open_weights=True,
+            public_training_code=None,
+            public_training_data=None,
+            use_instructions=None,
+            training_datasets=None,
         )
     except AttributeError as e:
         logger.warning(
@@ -252,5 +406,17 @@ def model_meta_from_sentence_transformers(model: SentenceTransformer) -> ModelMe
             revision=None,
             languages=None,
             release_date=None,
+            n_parameters=None,
+            memory_usage_mb=None,
+            max_tokens=None,
+            embed_dim=None,
+            license=None,
+            open_weights=True,
+            public_training_code=None,
+            public_training_data=None,
+            similarity_fn_name=None,
+            use_instructions=None,
+            training_datasets=None,
+            framework=[],
         )
     return meta
