@@ -8,9 +8,8 @@ import torch
 
 from mteb.encoder_interface import Encoder
 from mteb.model_meta import ModelMeta
-
-from .repllama_models import RepLLaMAWrapper
-from .wrapper import Wrapper
+from mteb.models.repllama_models import RepLLaMAWrapper
+from mteb.models.wrapper import Wrapper
 
 logger = logging.getLogger(__name__)
 
@@ -51,12 +50,12 @@ promptriever_llama2 = ModelMeta(
         torch_dtype=torch.bfloat16,
     ),
     name="samaya-ai/promptriever-llama2-7b-v1",
-    languages=["eng_Latn"],
+    languages=["eng-Latn"],
     open_weights=True,
     revision="01c7f73d771dfac7d292323805ebc428287df4f9-30b14e3813c0fa45facfd01a594580c3fe5ecf23",  # base-peft revision
     release_date="2024-09-15",
-    n_parameters=7_000_000,
-    memory_usage=None,
+    n_parameters=7_000_000_000,
+    memory_usage_mb=27,
     max_tokens=4096,
     embed_dim=4096,
     license="apache-2.0",
@@ -65,6 +64,8 @@ promptriever_llama2 = ModelMeta(
     similarity_fn_name="cosine",
     framework=["PyTorch", "Tevatron"],
     use_instructions=True,
+    public_training_code=None,
+    public_training_data=None,
 )
 
 promptriever_llama3 = ModelMeta(
@@ -76,13 +77,16 @@ promptriever_llama3 = ModelMeta(
         torch_dtype=torch.bfloat16,
     ),
     name="samaya-ai/promptriever-llama3.1-8b-v1",
-    languages=["eng_Latn"],
+    languages=["eng-Latn"],
     open_weights=True,
     revision="48d6d0fc4e02fb1269b36940650a1b7233035cbb-2ead22cfb1b0e0c519c371c63c2ab90ffc511b8a",  # base-peft revision
-    training_datasets={"samaya-ai/msmarco-w-instructions": ["train"]},
+    training_datasets={
+        "samaya-ai/msmarco-w-instructions": ["train"],
+        "mMARCO-NL": ["train"],  # translation not trained on
+    },
     release_date="2024-09-15",
-    n_parameters=8_000_000,
-    memory_usage=None,
+    n_parameters=8_000_000_000,
+    memory_usage_mb=31,
     max_tokens=8192,
     embed_dim=4096,
     license="apache-2.0",
@@ -90,9 +94,10 @@ promptriever_llama3 = ModelMeta(
     similarity_fn_name="cosine",
     framework=["PyTorch", "Tevatron"],
     use_instructions=True,
+    public_training_code=None,
+    public_training_data=None,
 )
 
-
 promptriever_llama3_instruct = ModelMeta(
     loader=_loader(
         RepLLaMAWrapper,
@@ -102,20 +107,25 @@ promptriever_llama3_instruct = ModelMeta(
         torch_dtype=torch.bfloat16,
     ),
     name="samaya-ai/promptriever-llama3.1-8b-instruct-v1",
-    languages=["eng_Latn"],
+    languages=["eng-Latn"],
     open_weights=True,
     revision="5206a32e0bd3067aef1ce90f5528ade7d866253f-8b677258615625122c2eb7329292b8c402612c21",  # base-peft revision
     release_date="2024-09-15",
-    n_parameters=8_000_000,
-    memory_usage=None,
+    n_parameters=8_000_000_000,
+    memory_usage_mb=31,
     max_tokens=8192,
     embed_dim=4096,
-    training_datasets={"samaya-ai/msmarco-w-instructions": ["train"]},
+    training_datasets={
+        "samaya-ai/msmarco-w-instructions": ["train"],
+        "mMARCO-NL": ["train"],  # translation not trained on
+    },
     license="apache-2.0",
     reference="https://huggingface.co/samaya-ai/promptriever-llama3.1-8b-instruct-v1",
     similarity_fn_name="cosine",
     framework=["PyTorch", "Tevatron"],
     use_instructions=True,
+    public_training_code=None,
+    public_training_data=None,
 )
 
 promptriever_mistral_v1 = ModelMeta(
@@ -127,13 +137,16 @@ promptriever_mistral_v1 = ModelMeta(
         torch_dtype=torch.bfloat16,
     ),
     name="samaya-ai/promptriever-mistral-v0.1-7b-v1",
-    languages=["eng_Latn"],
+    languages=["eng-Latn"],
     open_weights=True,
     revision="7231864981174d9bee8c7687c24c8344414eae6b-876d63e49b6115ecb6839893a56298fadee7e8f5",  # base-peft revision
     release_date="2024-09-15",
-    n_parameters=7_000_000,
-    training_datasets={"samaya-ai/msmarco-w-instructions": ["train"]},
-    memory_usage=None,
+    n_parameters=7_000_000_000,
+    memory_usage_mb=27,
+    training_datasets={
+        "samaya-ai/msmarco-w-instructions": ["train"],
+        "mMARCO-NL": ["train"],  # translation not trained on
+    },
     max_tokens=4096,
     embed_dim=4096,
     license="apache-2.0",
@@ -141,4 +154,6 @@ promptriever_mistral_v1 = ModelMeta(
     similarity_fn_name="cosine",
     framework=["PyTorch", "Tevatron"],
     use_instructions=True,
+    public_training_code=None,
+    public_training_data=None,
 )
