@@ -8,9 +8,13 @@ import numpy as np
 
 from mteb.encoder_interface import PromptType
 from mteb.model_meta import ModelMeta
+from mteb.models.wrapper import Wrapper
 from mteb.requires_package import requires_package
 
-from .wrapper import Wrapper
+VOYAGE_TRAINING_DATA = {
+    # Self-reported (message from VoyageAI member)
+    # synthetic data
+}
 
 
 def token_limit(max_tpm: int, interval: int = 60):
@@ -74,7 +78,7 @@ class VoyageWrapper(Wrapper):
         model_prompts: dict[str, str] | None = None,
         **kwargs,
     ) -> None:
-        requires_package(self, "voyageai", "Voyage")
+        requires_package(self, "voyageai", model_name, "pip install 'mteb[voyageai]'")
         import voyageai
 
         self._client = voyageai.Client(max_retries=max_retries)
@@ -94,7 +98,9 @@ class VoyageWrapper(Wrapper):
         prompt_type: PromptType | None = None,
         **kwargs: Any,
     ) -> np.ndarray:
-        input_type = self.model_prompts.get(prompt_type.value, "document")
+        prompt_name = self.get_prompt_name(self.model_prompts, task_name, prompt_type)
+        input_type = self.model_prompts.get(prompt_name, "document")
+
         return self._batched_encode(sentences, batch_size, input_type)
 
     def _batched_encode(
@@ -151,12 +157,15 @@ voyage_large_2_instruct = ModelMeta(
     embed_dim=1024,
     open_weights=False,
     n_parameters=None,
-    memory_usage=None,
+    memory_usage_mb=None,
     license=None,
     reference="https://blog.voyageai.com/2024/05/05/voyage-large-2-instruct-instruction-tuned-and-rank-1-on-mteb/",
     similarity_fn_name="cosine",
     framework=["API"],
     use_instructions=True,
+    training_datasets=VOYAGE_TRAINING_DATA,
+    public_training_code=None,
+    public_training_data=None,
 )
 
 voyage_finance_2 = ModelMeta(
@@ -173,12 +182,15 @@ voyage_finance_2 = ModelMeta(
     embed_dim=1024,
     open_weights=False,
     n_parameters=None,
-    memory_usage=None,
+    memory_usage_mb=None,
     license=None,
     reference="https://blog.voyageai.com/2024/06/03/domain-specific-embeddings-finance-edition-voyage-finance-2/",
     similarity_fn_name="cosine",
     framework=["API"],
     use_instructions=True,
+    training_datasets=VOYAGE_TRAINING_DATA,
+    public_training_code=None,
+    public_training_data=None,
 )
 
 voyage_law_2 = ModelMeta(
@@ -195,12 +207,15 @@ voyage_law_2 = ModelMeta(
     embed_dim=1024,
     open_weights=False,
     n_parameters=None,
-    memory_usage=None,
+    memory_usage_mb=None,
     license=None,
     reference="https://blog.voyageai.com/2024/04/15/domain-specific-embeddings-and-retrieval-legal-edition-voyage-law-2/",
     similarity_fn_name="cosine",
     framework=["API"],
     use_instructions=True,
+    training_datasets=VOYAGE_TRAINING_DATA,
+    public_training_code=None,
+    public_training_data=None,
 )
 
 voyage_code_2 = ModelMeta(
@@ -217,16 +232,45 @@ voyage_code_2 = ModelMeta(
     embed_dim=1536,
     open_weights=False,
     n_parameters=None,
-    memory_usage=None,
+    memory_usage_mb=None,
     license=None,
     reference="https://blog.voyageai.com/2024/01/23/voyage-code-2-elevate-your-code-retrieval/",
     similarity_fn_name="cosine",
     framework=["API"],
     use_instructions=True,
+    training_datasets=VOYAGE_TRAINING_DATA,
+    public_training_code=None,
+    public_training_data=None,
 )
 
+voyage_code_3 = ModelMeta(
+    name="voyageai/voyage-code-3",
+    revision="1",
+    release_date="2024-12-04",
+    languages=None,  # supported languages not specified
+    loader=partial(  # type: ignore
+        VoyageWrapper,
+        model_name="voyage-code-3",
+        model_prompts=model_prompts,
+    ),
+    max_tokens=32000,
+    embed_dim=1024,
+    open_weights=False,
+    n_parameters=None,
+    memory_usage_mb=None,
+    license=None,
+    reference="https://blog.voyageai.com/2024/12/04/voyage-code-3/",
+    similarity_fn_name="cosine",
+    framework=["API"],
+    use_instructions=True,
+    training_datasets=VOYAGE_TRAINING_DATA,  # src: private communication with Voyage
+    public_training_code=None,
+    public_training_data=None,
+)
+
+
 voyage_large_2 = ModelMeta(
-    name="voyage-large-2",  # Date of publication of this post https://blog.voyageai.com/2023/10/29/voyage-embeddings/
+    name="voyageai/voyage-large-2",  # Date of publication of this post https://blog.voyageai.com/2023/10/29/voyage-embeddings/
     revision="1",
     release_date="2023-10-29",
     languages=None,  # supported languages not specified
@@ -239,12 +283,15 @@ voyage_large_2 = ModelMeta(
     embed_dim=1536,
     open_weights=False,
     n_parameters=None,
-    memory_usage=None,
+    memory_usage_mb=None,
     license=None,
     reference="https://blog.voyageai.com/2023/10/29/voyage-embeddings/",
     similarity_fn_name="cosine",
     framework=["API"],
     use_instructions=True,
+    training_datasets=VOYAGE_TRAINING_DATA,
+    public_training_code=None,
+    public_training_data=None,
 )
 
 voyage_2 = ModelMeta(
@@ -261,12 +308,15 @@ voyage_2 = ModelMeta(
     embed_dim=1024,
     open_weights=False,
     n_parameters=None,
-    memory_usage=None,
+    memory_usage_mb=None,
     license=None,
     reference="https://blog.voyageai.com/2023/10/29/voyage-embeddings/",
     similarity_fn_name="cosine",
     framework=["API"],
     use_instructions=True,
+    training_datasets=VOYAGE_TRAINING_DATA,
+    public_training_code=None,
+    public_training_data=None,
 )
 voyage_multilingual_2 = ModelMeta(
     name="voyageai/voyage-multilingual-2",
@@ -282,12 +332,15 @@ voyage_multilingual_2 = ModelMeta(
     embed_dim=1024,
     open_weights=False,
     n_parameters=None,
-    memory_usage=None,
+    memory_usage_mb=None,
     license=None,
     reference="https://blog.voyageai.com/2024/06/10/voyage-multilingual-2-multilingual-embedding-model/",
     similarity_fn_name="cosine",
     framework=["API"],
     use_instructions=True,
+    training_datasets=VOYAGE_TRAINING_DATA,
+    public_training_code=None,
+    public_training_data=None,
 )
 
 voyage_3 = ModelMeta(
@@ -304,12 +357,15 @@ voyage_3 = ModelMeta(
     embed_dim=1024,
     open_weights=False,
     n_parameters=None,
-    memory_usage=None,
+    memory_usage_mb=None,
     license=None,
     reference="https://blog.voyageai.com/2024/09/18/voyage-3/",
     similarity_fn_name="cosine",
     framework=["API"],
     use_instructions=True,
+    training_datasets=VOYAGE_TRAINING_DATA,
+    public_training_code=None,
+    public_training_data=None,
 )
 
 voyage_3_lite = ModelMeta(
@@ -326,10 +382,100 @@ voyage_3_lite = ModelMeta(
     embed_dim=512,
     open_weights=False,
     n_parameters=None,
-    memory_usage=None,
+    memory_usage_mb=None,
     license=None,
     reference="https://blog.voyageai.com/2024/09/18/voyage-3/",
     similarity_fn_name="cosine",
     framework=["API"],
     use_instructions=True,
+    training_datasets=VOYAGE_TRAINING_DATA,
+    public_training_code=None,
+    public_training_data=None,
+)
+
+voyage_3_exp = ModelMeta(
+    name="voyageai/voyage-3-m-exp",
+    revision="1",
+    release_date="2025-01-08",
+    languages=["eng-Latn"],
+    loader=partial(
+        VoyageWrapper,
+        model_name="voyage-3-m-exp",
+        model_prompts=model_prompts,
+    ),
+    max_tokens=32000,
+    embed_dim=2048,
+    open_weights=False,
+    # from their card https://huggingface.co/voyageai/voyage-3-m-exp#model-information
+    n_parameters=int(6918 * 1e6),
+    memory_usage_mb=None,
+    license=None,
+    reference="https://huggingface.co/voyageai/voyage-3-m-exp",
+    similarity_fn_name="cosine",
+    framework=["API"],
+    use_instructions=True,
+    training_datasets={
+        # MTEB(eng, v1) training data:
+        "AmazonPolarityClassification": ["train"],
+        "AmazonReviewsClassification": ["train"],
+        "EmotionClassification": ["train"],
+        "HotpotQA": ["train"],
+        "ImdbClassification": ["train"],
+        "MTOPDomainClassification": ["train"],
+        "MTOPIntentClassification": ["train"],
+        "MindSmallReranking": ["train"],
+        "MassiveIntentClassification": ["train"],
+        "MassiveScenarioClassification": ["train"],
+        "MedrxivClusteringP2P": ["train"],
+        "MedrxivClusteringS2S": ["train"],
+        "STS12": ["train"],
+        "STSBenchmark": ["train"],
+        "StackOverflowDupQuestions": ["train"],
+        "ToxicConversationsClassification": ["train"],
+        "TweetSentimentExtractionClassification": ["train"],
+        "BiorxivClusteringP2P": ["train"],
+        "BiorxivClusteringS2S": ["train"],
+        "Banking77Classification": ["train"],
+        "ArguAna": ["train"],
+        "ArguAna-PL": ["train"],
+        "ArguAna-NL": ["train"],  # translation not trained on
+        "NanoArguAnaRetrieval": ["train"],
+        "STS22": ["train"],
+        "AmazonCounterfactualClassification": ["train"],
+        "ArxivClusteringP2P": ["train"],
+        "ArxivClusteringS2S": ["train"],
+        "NQ": ["train"],
+        "SciFact": ["train"],
+        "QuoraRetrieval": ["train"],
+        "NanoQuoraRetrieval": ["train"],
+        "NQHardNegatives": ["train"],
+        "NanoNQRetrieval": ["train"],
+        "NQ-PL": ["train"],  # translation not trained on
+        "NQ-NL": ["train"],  # translation not trained on
+        "NFCorpus": ["train"],
+        "FEVERHardNegatives": ["train"],
+        "NanoFEVERRetrieval": ["train"],
+        "FEVER-NL": ["train"],  # translation not trained on
+        "FiQA2018-NL": ["train"],  # translation not trained on
+        "BiorxivClusteringP2P.v2": ["train"],
+        "BiorxivClusteringS2S.v2": ["train"],
+        "MedrxivClusteringP2P.v2": ["train"],
+        "MedrxivClusteringS2S.v2": ["train"],
+        "MSMARCO": ["train"],
+        "MSMARCOHardNegatives": ["train"],
+        "NanoMSMARCORetrieval": ["train"],
+        "MSMARCO-PL": ["train"],  # translation not trained on
+        "mMARCO-NL": ["train"],  # translation not trained on
+        "HotpotQA-PL": ["train"],  # translation not trained on
+        "HotpotQA-NL": ["train"],  # translation not trained on
+        "HotpotQAHardNegatives": ["train"],
+        "FEVER": ["train"],
+        "FiQA2018": ["train"],
+        "DBPedia": ["train"],
+        "TRECCOVID": ["train"],
+        "ArxivClusteringP2P.v2": ["train"],
+        "STSBenchmarkMultilingualSTS": ["train"],  # translated, not trained on
+    },
+    public_training_code=None,
+    public_training_data=None,
 )
