@@ -9,9 +9,8 @@ class ArxivClassification(AbsTaskClassification):
         name="ArxivClassification",
         description="Classification Dataset of Arxiv Papers",
         dataset={
-            "path": "ccdv/arxiv-classification",
-            "revision": "f9bd92144ed76200d6eb3ce73a8bd4eba9ffdc85",
-            "trust_remote_code": True,
+            "path": "mteb/ArxivClassification",
+            "revision": "5e80893bf045abefbf8cbe5d713bddc91ae158d5",
         },
         reference="https://ieeexplore.ieee.org/document/8675939",
         type="Classification",
@@ -27,14 +26,16 @@ class ArxivClassification(AbsTaskClassification):
         annotations_creators="derived",
         dialect=[],
         sample_creation="found",
-        bibtex_citation="""@ARTICLE{8675939,
-        author={He, Jun and Wang, Liqun and Liu, Liu and Feng, Jiao and Wu, Hao},
-        journal={IEEE Access}, 
-        title={Long Document Classification From Local Word Glimpses via Recurrent Attention Learning}, 
-        year={2019},
-        volume={7},
-        number={},
-        pages={40707-40718},
-        doi={10.1109/ACCESS.2019.2907992}
-        }""",
+        bibtex_citation=r"""
+@article{8675939,
+  author = {He, Jun and Wang, Liqun and Liu, Liu and Feng, Jiao and Wu, Hao},
+  doi = {10.1109/ACCESS.2019.2907992},
+  journal = {IEEE Access},
+  number = {},
+  pages = {40707-40718},
+  title = {Long Document Classification From Local Word Glimpses via Recurrent Attention Learning},
+  volume = {7},
+  year = {2019},
+}
+""",
     )
