@@ -27,13 +27,15 @@ class FrenkEnClassification(AbsTaskClassification):
         annotations_creators="derived",
         dialect=[],
         sample_creation="found",
-        bibtex_citation="""@misc{ljubešić2019frenk,
-        title={The FRENK Datasets of Socially Unacceptable Discourse in Slovene and English}, 
-        author={Nikola Ljubešić and Darja Fišer and Tomaž Erjavec},
-        year={2019},
-        eprint={1906.02045},
-        archivePrefix={arXiv},
-        primaryClass={cs.CL},
-        url={https://arxiv.org/abs/1906.02045}
-        }""",
+        bibtex_citation=r"""
+@misc{ljubešić2019frenk,
+  archiveprefix = {arXiv},
+  author = {Nikola Ljubešić and Darja Fišer and Tomaž Erjavec},
+  eprint = {1906.02045},
+  primaryclass = {cs.CL},
+  title = {The FRENK Datasets of Socially Unacceptable Discourse in Slovene and English},
+  url = {https://arxiv.org/abs/1906.02045},
+  year = {2019},
+}
+""",
     )
