@@ -40,13 +40,15 @@ class SouthAfricanLangClassification(AbsTaskClassification):
         annotations_creators="expert-annotated",
         dialect=[],
         sample_creation="found",
-        bibtex_citation="""@misc{south-african-language-identification,
-    author = {ExploreAI Academy, Joanne M},
-    title = {South African Language Identification},
-    publisher = {Kaggle},
-    year = {2022},
-    url = {https://kaggle.com/competitions/south-african-language-identification}
-}""",
+        bibtex_citation=r"""
+@misc{south-african-language-identification,
+  author = {ExploreAI Academy, Joanne M},
+  publisher = {Kaggle},
+  title = {South African Language Identification},
+  url = {https://kaggle.com/competitions/south-african-language-identification},
+  year = {2022},
+}
+""",
     )
 
     def dataset_transform(self) -> None:
