@@ -10,9 +10,8 @@ class SwedishSentimentClassification(AbsTaskClassification):
         description="Dataset of Swedish reviews scarped from various public available websites",
         reference="https://huggingface.co/datasets/swedish_reviews",
         dataset={
-            "path": "timpal0l/swedish_reviews",
-            "revision": "105ba6b3cb99b9fd64880215be469d60ebf44a1b",
-            "trust_remote_code": True,
+            "path": "mteb/SwedishSentimentClassification",
+            "revision": "39e35f55d58338ebd602f8d83b52cfe027f5146a",
         },
         type="Classification",
         category="s2s",
@@ -29,8 +28,3 @@ class SwedishSentimentClassification(AbsTaskClassification):
         sample_creation="found",
         bibtex_citation="",
     )
-
-    def dataset_transform(self):
-        self.dataset = self.stratified_subsampling(
-            self.dataset, seed=self.seed, splits=["validation", "test"]
-        )
