@@ -27,19 +27,21 @@ class AILACasedocs(AbsTaskRetrieval):
         annotations_creators="derived",
         dialect=None,
         sample_creation="found",
-        bibtex_citation="""@dataset{paheli_bhattacharya_2020_4063986,
-  author       = {Paheli Bhattacharya and
-                  Kripabandhu Ghosh and
-                  Saptarshi Ghosh and
-                  Arindam Pal and
-                  Parth Mehta and
-                  Arnab Bhattacharya and
-                  Prasenjit Majumder},
-  title        = {AILA 2019 Precedent \& Statute Retrieval Task},
-  month        = oct,
-  year         = 2020,
-  publisher    = {Zenodo},
-  doi          = {10.5281/zenodo.4063986},
-  url          = {https://doi.org/10.5281/zenodo.4063986}
-}""",
+        bibtex_citation=r"""
+@dataset{paheli_bhattacharya_2020_4063986,
+  author = {Paheli Bhattacharya and
+Kripabandhu Ghosh and
+Saptarshi Ghosh and
+Arindam Pal and
+Parth Mehta and
+Arnab Bhattacharya and
+Prasenjit Majumder},
+  doi = {10.5281/zenodo.4063986},
+  month = oct,
+  publisher = {Zenodo},
+  title = {AILA 2019 Precedent \& Statute Retrieval Task},
+  url = {https://doi.org/10.5281/zenodo.4063986},
+  year = {2020},
+}
+""",
     )
