@@ -5,6 +5,7 @@ import logging
 import pytest
 
 from mteb import AbsTask
+from mteb.abstasks.aggregated_task import AbsTaskAggregate
 from mteb.abstasks.TaskMetadata import TaskMetadata
 from mteb.overview import get_tasks
 
@@ -12,7 +13,6 @@ from mteb.overview import get_tasks
 _HISTORIC_DATASETS = [
     "PolEmo2.0-IN",
     "PolEmo2.0-OUT",
-    "AllegroReviews",
     "PAC",
     "TNews",
     "IFlyTek",
@@ -26,7 +26,6 @@ _HISTORIC_DATASETS = [
     "TenKGnadClusteringS2S",
     "ArxivClusteringP2P",
     "ArxivClusteringS2S",
-    "BigPatentClustering",
     "RedditClustering",
     "RedditClusteringP2P",
     "StackExchangeClustering",
@@ -52,13 +51,12 @@ _HISTORIC_DATASETS = [
     "TwitterHjerneRetrieval",
     "GerDaLIR",
     "GerDaLIRSmall",
-    "GermanDPR",
-    "GermanQuAD-Retrieval",
     "LegalQuAD",
     "AILACasedocs",
     "AILAStatutes",
     "ArguAna",
     "ClimateFEVER",
+    "CQADupstackRetrieval",
     "CQADupstackAndroidRetrieval",
     "CQADupstackEnglishRetrieval",
     "CQADupstackGamingRetrieval",
@@ -178,6 +176,23 @@ _HISTORIC_DATASETS = [
     "TamilNewsClassification",
     "TenKGnadClusteringP2P.v2",
     "TenKGnadClusteringS2S.v2",
+    "ClimateFEVERHardNegatives",
+    "DBPediaHardNegatives",
+    "FEVERHardNegatives",
+    "HotpotQAHardNegatives",
+    "MSMARCOHardNegatives",
+    "NQHardNegatives",
+    "QuoraRetrievalHardNegatives",
+    "TopiOCQAHardNegatives",
+    "MIRACLRetrievalHardNegatives",
+    "NeuCLIR2022RetrievalHardNegatives",
+    "NeuCLIR2023RetrievalHardNegatives",
+    "DBPedia-PLHardNegatives",
+    "HotpotQA-PLHardNegatives",
+    "MSMARCO-PLHardNegatives",
+    "NQ-PLHardNegatives",
+    "Quora-PLHardNegatives",
+    "RiaNewsRetrievalHardNegatives",
 ]
 
 
@@ -352,23 +367,54 @@ def test_filled_metadata_is_filled():
     )
 
 
+def test_invalid_metadata_eval_lang_is_invalid():
+    with pytest.raises(ValueError):
+        TaskMetadata(
+            name="MyTask",
+            dataset={
+                "path": "test/dataset",
+                "revision": "1.0",
+            },
+            description="testing",
+            reference="https://aclanthology.org/W19-6138/",
+            type="Classification",
+            category="s2s",
+            modalities=["text"],
+            eval_splits=["test"],
+            eval_langs=["eng_Latn"],  # uses underscore instead of dash
+            main_score="map",
+            date=("2021-01-01", "2021-12-31"),
+            domains=["Non-fiction", "Written"],
+            license="mit",
+            task_subtypes=["Thematic clustering"],
+            annotations_creators="expert-annotated",
+            dialect=[],
+            sample_creation="found",
+            bibtex_citation="Someone et al",
+        ).validate_metadata()
+
+
 def test_all_metadata_is_filled_and_valid():
     all_tasks = get_tasks()
 
     unfilled_metadata = []
+    invalid_metadata = []
     for task in all_tasks:
-        if (
-            task.metadata.name not in _HISTORIC_DATASETS
-            and task.metadata.name.replace("HardNegatives", "")
-            not in _HISTORIC_DATASETS
+        if task.metadata.name in _HISTORIC_DATASETS or isinstance(
+            task, AbsTaskAggregate
         ):
-            if not task.metadata.is_filled() and (
-                not task.metadata.validate_metadata()
-            ):
-                unfilled_metadata.append(task.metadata.name)
-    if unfilled_metadata:
+            continue
+
+        if not task.metadata.is_filled():
+            unfilled_metadata.append(task.metadata.name)
+        else:
+            if task.metadata.validate_metadata() is not None:
+                invalid_metadata.append(task.metadata.name)
+
+    if unfilled_metadata or invalid_metadata:
         raise ValueError(
-            f"The metadata of the following datasets is not filled: {unfilled_metadata}"
+            f"The metadata of the following datasets is not filled: {unfilled_metadata}."
+            + f"The metadata of the following datasets is invalid: {invalid_metadata}."
         )
 
 
@@ -513,17 +559,17 @@ def test_disallow_trust_remote_code_in_new_datasets():
         "SwednClusteringS2S",
     ]
 
-    assert (
-        135 == len(exceptions)
-    ), "The number of exceptions has changed. Please do not add new datasets to this list."
+    assert 135 == len(exceptions), (
+        "The number of exceptions has changed. Please do not add new datasets to this list."
+    )
 
     exceptions = []
 
     for task in get_tasks():
         if task.metadata.dataset.get("trust_remote_code", False):
-            assert (
-                task.metadata.name not in exceptions
-            ), f"Dataset {task.metadata.name} should not trust remote code"
+            assert task.metadata.name not in exceptions, (
+                f"Dataset {task.metadata.name} should not trust remote code"
+            )
 
 
 def test_empy_descriptive_stat_in_new_datasets():
@@ -1085,26 +1131,29 @@ def test_empy_descriptive_stat_in_new_datasets():
         "SummEvalFrSummarization.v2",
     ]
 
-    assert (
-        553 == len(exceptions)
-    ), "The number of exceptions has changed. Please do not add new datasets to this list."
+    assert 553 == len(exceptions), (
+        "The number of exceptions has changed. Please do not add new datasets to this list."
+    )
 
     exceptions = []
 
     for task in get_tasks():
         if task.metadata.descriptive_stats is None:
-            assert (
-                task.metadata.name not in exceptions
-            ), f"Dataset {task.metadata.name} should have descriptive stats"
+            assert task.metadata.name not in exceptions, (
+                f"Dataset {task.metadata.name} should have descriptive stats"
+            )
 
 
 @pytest.mark.parametrize("task", get_tasks())
 def test_eval_langs_correctly_specified(task: AbsTask):
+    if task.metadata.name in ["VisualSTS17Eng", "VisualSTS17Multilingual"]:
+        return
+
     if task.is_multilingual:
-        assert isinstance(
-            task.metadata.eval_langs, dict
-        ), f"{task.metadata.name} should have eval_langs as a dict"
+        assert isinstance(task.metadata.eval_langs, dict), (
+            f"{task.metadata.name} should have eval_langs as a dict"
+        )
     else:
-        assert isinstance(
-            task.metadata.eval_langs, list
-        ), f"{task.metadata.name} should have eval_langs as a list"
+        assert isinstance(task.metadata.eval_langs, list), (
+            f"{task.metadata.name} should have eval_langs as a list"
+        )
